@@ -1,18 +1,17 @@
-#!/usr/bin/env python
-
 from collections import Counter
 from Levenshtein import hamming
 import _pickle as pickle
 import pandas as pd
 import sqlite3
 import random
+import os
 
 from .parser import parse_fasta
 from .preprocessor import Preprocessor
 
 
 splits = []
-VALID_OUTPUT_FORMATS = ['csv', 'xlsx', 'json', 'html']
+VALID_OUTPUT_FORMATS = ['dataframe', 'csv', 'xlsx', 'json', 'html']
 
 class Matcher(Preprocessor):
   '''
@@ -33,8 +32,8 @@ class Matcher(Preprocessor):
                database='',
                one_match=False,
                output_df=True,
-               output_name='',
-               output_format='csv'):
+               output_format='csv',
+               output_name=''):
 
     if type(query) == list:
       self.query = query
@@ -77,10 +76,10 @@ class Matcher(Preprocessor):
       else:
         self.preprocess_format = 'pickle'
 
-    if self.output_format != '' and self.output_format not in VALID_OUTPUT_FORMATS:
-      raise ValueError('Invalid output format, please choose csv, xlsx, json, or html.')
+    if self.output_format not in VALID_OUTPUT_FORMATS:
+      raise ValueError('Invalid output format, please choose dataframe, csv, xlsx, json, or html.')
 
-    super().__init__(self.proteome, self.split, self.preprocess_format, self.database, True)
+    super().__init__(self.proteome, self.split, self.preprocess_format, self.database)
 
   def split_peptide(self, seq, k):
     '''
@@ -98,7 +97,7 @@ class Matcher(Preprocessor):
     Read in the already created pickle files for each dictionary in the
     preprocessing step.
     '''
-    name = self.proteome.replace('.fa', '').replace('.fasta', '')
+    name = os.path.splitext(self.proteome)[0]
     with open(name + '_' + str(self.split) + 'mers' + '.pickle', 'rb') as f:
       kmer_dict = pickle.load(f)
     with open(name + '_names.pickle', 'rb') as f:
@@ -513,7 +512,7 @@ class Matcher(Preprocessor):
       else:
         df = self.dataframe_mismatch_matches(all_matches)
 
-      if self.output_format == '':
+      if self.output_format == 'dataframe':
         return df
       else:
         self.output_matches(df)
@@ -595,4 +594,4 @@ class Matcher(Preprocessor):
     elif self.output_format == 'json':
       return df.to_json(self.output_name + '.json')
     elif self.output_format == 'html':
-      return df.to_html()
\ No newline at end of file
+      return df.to_html()
